==> jollycv-1.1.0.tar.bz2: jollycv-1.1.0/src/jcv_z80.h <==
/*
Copyright (c) 2020-2022 Rupert Carmichael
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef JCV_Z80_H
#define JCV_Z80_H

void jcv_z80_cyc_store(uint32_t);
uint32_t jcv_z80_cyc_restore(void);
void jcv_z80_init(void);
void jcv_z80_irq_clr(void);
void jcv_z80_irq(uint8_t data);
void jcv_z80_nmi(void);
void jcv_z80_reset(void);
void jcv_z80_delay(uint32_t);
uint32_t jcv_z80_exec(void);
uint32_t jcv_z80_run(uint32_t);

void jcv_z80_state_load(uint8_t*);
void jcv_z80_state_save(uint8_t*);

#endif

==> jollycv-2.0.0.tar.bz2: jollycv-2.0.0/src/jcv_z80.h <==
/*
Copyright (c) 2020-2022 Rupert Carmichael
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef JCV_Z80_H
#define JCV_Z80_H

void jcv_z80_cyc_store(uint32_t);
uint32_t jcv_z80_cyc_restore(void);
void jcv_z80_init(void);
void jcv_z80_irq(uint8_t data);
void jcv_z80_irq_ff(void);
void jcv_z80_nmi(void);
void jcv_z80_reset(void);
void jcv_z80_delay(uint32_t);
uint32_t jcv_z80_exec(void);
uint32_t jcv_z80_run(uint32_t);

void jcv_z80_state_load(uint8_t*);
void jcv_z80_state_save(uint8_t*);

extern uint8_t (*jcv_z80_io_rd)(uint16_t);
extern void (*jcv_z80_io_wr)(uint16_t, uint8_t);

extern uint8_t (*jcv_z80_mem_rd)(uint16_t);
extern void (*jcv_z80_mem_wr)(uint16_t, uint8_t);

#endif
